==> jc-1.4.0.tar.gz: javax/swing/event/DocumentEvent__24EventType.h <==
// public class javax.swing.event.DocumentEvent$EventType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c97483217b49a23a javax_swing_event_DocumentEvent__24EventType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_event_DocumentEvent__24EventType_H_
#define _JC_javax_swing_event_DocumentEvent__24EventType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_DocumentEvent__24EventType$object;

// Typedefs
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_refs	_jc_javax_swing_event_DocumentEvent__24EventType$sub_refs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs	_jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$refs	_jc_javax_swing_event_DocumentEvent__24EventType$refs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$nonrefs	_jc_javax_swing_event_DocumentEvent__24EventType$nonrefs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$object	_jc_javax_swing_event_DocumentEvent__24EventType$object;

typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$fields_struct	_jc_javax_swing_event_DocumentEvent__24EventType$fields_struct;
typedef const struct _jc_javax_swing_event_DocumentEvent__24EventType$vmethods	_jc_javax_swing_event_DocumentEvent__24EventType$vmethods;
typedef const struct _jc_javax_swing_event_DocumentEvent__24EventType$vtable	_jc_javax_swing_event_DocumentEvent__24EventType$vtable;
typedef const struct _jc_javax_swing_event_DocumentEvent__24EventType$vtype	_jc_javax_swing_event_DocumentEvent__24EventType$vtype;

// Class fields structure
struct _jc_javax_swing_event_DocumentEvent__24EventType$fields_struct {
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*CHANGE;
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*INSERT;
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*REMOVE;
};
extern _jc_javax_swing_event_DocumentEvent__24EventType$fields_struct _jc_javax_swing_event_DocumentEvent__24EventType$class_fields;

// Constructors
extern void _jc_javax_swing_event_DocumentEvent__24EventType$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_event_DocumentEvent__24EventType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_DocumentEvent__24EventType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_swing_event_DocumentEvent__24EventType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_event_DocumentEvent__24EventType$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *);
};

// Vtable
struct _jc_javax_swing_event_DocumentEvent__24EventType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_DocumentEvent__24EventType$vmethods	javax_swing_event_DocumentEvent__24EventType;
};

// Vtype
struct _jc_javax_swing_event_DocumentEvent__24EventType$vtype {
	_jc_type			type;
	_jc_javax_swing_event_DocumentEvent__24EventType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_refs {
	struct _jc_java_lang_String$object	*type;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_DocumentEvent__24EventType$refs {
    _jc_javax_swing_event_DocumentEvent__24EventType$sub_refs	javax_swing_event_DocumentEvent__24EventType;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_DocumentEvent__24EventType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs	javax_swing_event_DocumentEvent__24EventType;
};

// Object instance structure
struct _jc_javax_swing_event_DocumentEvent__24EventType$object {
	_jc_javax_swing_event_DocumentEvent__24EventType$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_DocumentEvent__24EventType$vtype	*vtype;
	_jc_javax_swing_event_DocumentEvent__24EventType$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_DocumentEvent__24EventType$vtype _jc_javax_swing_event_DocumentEvent__24EventType$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_DocumentEvent__24EventType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_DocumentEvent__24EventType$class_object;

#endif	/* _JC_javax_swing_event_DocumentEvent__24EventType_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/DocumentEvent__24EventType.h <==
// public class javax.swing.event.DocumentEvent$EventType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c97483217b49a23a javax_swing_event_DocumentEvent__24EventType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_event_DocumentEvent__24EventType_H_
#define _JC_javax_swing_event_DocumentEvent__24EventType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_DocumentEvent__24EventType$object;

// Typedefs
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_refs	_jc_javax_swing_event_DocumentEvent__24EventType$sub_refs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs	_jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$refs	_jc_javax_swing_event_DocumentEvent__24EventType$refs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$nonrefs	_jc_javax_swing_event_DocumentEvent__24EventType$nonrefs;
typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$object	_jc_javax_swing_event_DocumentEvent__24EventType$object;

typedef struct _jc_javax_swing_event_DocumentEvent__24EventType$fields_struct	_jc_javax_swing_event_DocumentEvent__24EventType$fields_struct;
typedef const struct _jc_javax_swing_event_DocumentEvent__24EventType$vmethods	_jc_javax_swing_event_DocumentEvent__24EventType$vmethods;
typedef const struct _jc_javax_swing_event_DocumentEvent__24EventType$vtable	_jc_javax_swing_event_DocumentEvent__24EventType$vtable;
typedef const struct _jc_javax_swing_event_DocumentEvent__24EventType$vtype	_jc_javax_swing_event_DocumentEvent__24EventType$vtype;

// Class fields structure
struct _jc_javax_swing_event_DocumentEvent__24EventType$fields_struct {
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*CHANGE;
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*INSERT;
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*REMOVE;
};
extern _jc_javax_swing_event_DocumentEvent__24EventType$fields_struct _jc_javax_swing_event_DocumentEvent__24EventType$class_fields;

// Constructors
extern void _jc_javax_swing_event_DocumentEvent__24EventType$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_event_DocumentEvent__24EventType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_DocumentEvent__24EventType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_swing_event_DocumentEvent__24EventType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_event_DocumentEvent__24EventType$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_DocumentEvent__24EventType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_DocumentEvent__24EventType$vmethods	javax_swing_event_DocumentEvent__24EventType;
};

// Vtype
struct _jc_javax_swing_event_DocumentEvent__24EventType$vtype {
	_jc_type			type;
	_jc_javax_swing_event_DocumentEvent__24EventType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_refs {
	struct _jc_java_lang_String$object	*type;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_DocumentEvent__24EventType$refs {
    _jc_javax_swing_event_DocumentEvent__24EventType$sub_refs	javax_swing_event_DocumentEvent__24EventType;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_DocumentEvent__24EventType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_DocumentEvent__24EventType$sub_nonrefs	javax_swing_event_DocumentEvent__24EventType;
};

// Object instance structure
struct _jc_javax_swing_event_DocumentEvent__24EventType$object {
	_jc_javax_swing_event_DocumentEvent__24EventType$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_DocumentEvent__24EventType$vtype	*vtype;
	_jc_javax_swing_event_DocumentEvent__24EventType$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_DocumentEvent__24EventType$vtype _jc_javax_swing_event_DocumentEvent__24EventType$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_DocumentEvent__24EventType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_DocumentEvent__24EventType$class_object;

#endif	/* _JC_javax_swing_event_DocumentEvent__24EventType_H_ */
